@@ -15,6 +15,8 @@ class Extractor(QtCore.QObject):
       QtCore.QObject.__init__(self)
 
       self.url = ''
+      self.stats = 'http://gerald.fauvelle.free.fr/stats/stats.php?url=%s'
+      
       self.userAgent = 'Firefox/3.5 Maemo Browser 1.7.4.8 RX-51 N900'
       self.urlPerturb = ''
       self.rideModel = RideModel(id)
@@ -71,6 +73,10 @@ class Extractor(QtCore.QObject):
       self.rideModel.Clear()
 
       if self.online and self.manager:
+         requestStats = QNetworkRequest( QtCore.QUrl(self.stats%self.url) )
+         requestStats.setRawHeader("User-Agent", self.userAgent)
+         reply = self.manager2.get(requestStats)
+      
          request = QNetworkRequest( QtCore.QUrl(self.url) )
          request.setRawHeader("User-Agent", self.userAgent)
          request.setRawHeader( "Accept-Encoding", "gzip, deflate" )
