@@ -60,7 +60,7 @@ class TrainTrainView(QtGui.QMainWindow):
       self.updateauto.setText(u"Rafraîchissement auto %s"%rate)
       for view in self.views.values():
          view.SetRefreshAutoRate(rate)
-      self.timer.setInterval(rate*1000)
+      self.timer.setInterval(int(rate)*1000)
 
    def AddRide(self):
       dlg = AddRideDlg(self.model.garesConf, self.tabW.currentIndex())
